@@ -656,7 +656,7 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "FleetRoutingClient":
         return self
 
     def __exit__(self, type, value, traceback):
